@@ -68,19 +68,19 @@ class Overrides {
        // Builtin extensions
         $builtin_extensions = Array(
             // Statically compiled extensions
-            'bcmath', 'bz2', 'calendar', 'core', 'ctype', 'date', 'dba', 'dom',
+            'calendar', 'core', 'ctype', 'date', 'dba',
             'ereg', 'exif', 'fileinfo', 'filter', 'ftp', 'gettext', 'hash',
-            'iconv', 'libxml', 'mbstring', 'openssl', 'pcntl', 'pcre', 'phar', 'posix',
-            'reflection', 'session', 'shmop', 'simplexml', 'soap', 'sockets',
+            'iconv', 'libxml', 'openssl', 'pcntl', 'pcre', 'phar', 'posix',
+            'reflection', 'session', 'shmop', 'sockets',
             'spl', 'standard', 'sysvmsg', 'sysvsem', 'sysvshm', 'tokenizer',
-            'wddx', 'xml', 'xmlreader', 'xmlwriter', 'zip', 'zlib',
+            'xmlreader', 'xmlwriter', 'zlib',
             // Dynamically compiled extensions
             'pdo',
             // Extensions provided or no longer builtin
             //'mhash', 'json',
         );
         foreach ($builtin_extensions as $builtin_extension) {
-            self::$_overrides[] = new Override('pear-pecl.php.net', $builtin_extension, 'builtin');
+            self::$_overrides[] = new Override('pear-pecl.php.net', $builtin_extension, 'builtin', '');
         }
     }
 
@@ -101,7 +101,8 @@ class Overrides {
                     Logger::warning('Ignoring line, too short: "%s" in file "%s".', $line, $overrides_file);
                     continue;
                 }
-                self::$_overrides[] = new Override('pear-'.$fields[0], $fields[1], $fields[2]);
+                $constraint = isset($fields[3]) ? $fields[3] : '';
+                self::$_overrides[] = new Override('pear-'.$fields[0], $fields[1], $fields[2], $constraint);
             }
             if (!feof($fh)) {
                 throw new \LogicException("Unable to read '$overrides_file'");
